##  Fact Sheet Subscriptions
Event | Description
---|---
SUBSCRIPTION_CREATED | A subscription is added to a fact sheet.
SUBSCRIPTION_UPDATED | A subscription is updated on a fact sheet.
SUBSCRIPTION_DELETED | A subscription is deleted from a fact sheet.


